.. image:: https://img.shields.io/pypi/v/popquotes.svg
   :target: https://pypi.org/project/popquotes

.. image:: https://img.shields.io/pypi/pyversions/popquotes.svg

.. image:: https://img.shields.io/travis/yougov/popquotes/master.svg
   :target: https://travis-ci.org/yougov/popquotes

.. image:: https://readthedocs.org/projects/popquotes/badge/?version=latest
   :target: https://popquotes.readthedocs.io/en/latest/?badge=latest
